// @madex/ex-ts-dao 是 ts 的 dao, 代码在 bitbucket/ex-js-dao 的 ts 分支上
import { coinType, ormDB, spotPairs } from "@madex/ex-ts-dao";
import { addCoin2Core, addPairToCore } from "../../../utils/coreSystemUtils";


export interface ListParam {
    symbol: string | any;

    page: number;

    size: number;
}

export interface AddParam {
    id: any,

    symbol: string;

    is_active: number;

    is_main: number;

    name: string;

    general_name: string;

    chain_type?: string;

    original_decimals: number;

    valid_decimals: number;

    contract?: string;

    contract_father?: string;

    enable_deposit?: number;

    enable_withdraw?: number;

    enable_transfer?: number;

    withdraw_fee?: number;

    withdraw_min?: number;

    deposit_min?: number;

    deposit_confirm_count: number;

    safe_confirm_count: number;

    explor_url?: string;

    icon_url?: string;

    describe_url?: string;

    forbid_info?: string;

    describe_summary?: string;

    total_amount?: number;


    supply_amount?: number;

    circulation_rate?: number;

    address_num?: number;

    price?: string;

    supply_time?: string;

    deflation_rate?: number;

    comment?: string;

    max_transfer_amount?: number;

    tag: string;

    forbid_info_related?: number;

    is_hidden?: number;

    main_status?: number;
}


export async function list(param: ListParam) {
    let where = {};
    if (param.symbol) {
        where["symbol"] = { [ormDB.Op.like]: `%${param.symbol}%` };
    }
    let resList = await coinType.prototype.findAndCount({
        where: where,
        limit: param.size,
        offset: (param.page - 1) * param.size,
        order: [["id", "desc"]],
        raw: true
    });
    return resList;
}

export const save = async (param: AddParam) => {
    let id = param.id;
    if (id) {
        delete param.id
        await coinType.prototype.update(param, {
            where: { id: id }
        })
    }
    else {
        await coinType.prototype.create(param);
    }

    return 'ok';
};

export const pushToCoreSystem = async (id: any) => {

    let where = { id: id, main_status: 0, is_main: 1 };

    let cfg = await coinType.prototype.find({
        where: where, raw: true
    });
    if (cfg) {
        let symbol = cfg.general_name;

        let optResult = await addCoin2Core(symbol);
        if (optResult) {
            await coinType.prototype.update({ main_status: 1 }, {
                where: where
            })
        }
    }
    return 'ok';

};

